#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

//#define VC_EXTRALEAN		// Exclude rarely-used stuff from Windows headers

#include <afxwin.h>         // MFC core and standard components
#include <afxctl.h>
#include <olectl.h>

#include <math.h>
#include <string.h>
#include <stdlib.h>

#define PI 3.1415926535897932384626433832795

#define OK								0
#define ERR_IMAGE_DIMENSIONS			1
#define ERR_PARAMETERS		            2
#define ERR_MISC						3
#define ERR_TOO_MANY_RESULTS			4
#define ERR_POINTER						99
#define ERR_NOT_ACTIVATED				100

#define FLAG_DELETABLE					1
#define FLAG_BGR_FLIPPED				2

struct colour_image
{
	unsigned char* pucImageData;
	long lImageWidth;
	long lImageHeight;
	long lImageDepth;
	long lXInc;
	long lYInc; 
	long lZInc;
	long lSize;
	long lFlags;
	colour_image* hLinkedImage;
};

struct rect_data
{
	long			lLeft;
	long			lTop;
	long			lRight;
	long			lBottom;
	rect_data*		rd_next;
	rect_data*		rd_prev;
};

struct transform_data
{
	double m_dM00;
	double m_dM01;
	double m_dM10;
	double m_dM11;
	double m_dX;
	double m_dY;
};

//Note
//Colour images are 24 bit BGR format by default.
//For most functions if the destination image is ** then if the destination pointer is null a new image will be created


//Image creation and destruction
long _stdcall FS_DeAllocateImage(colour_image* src);
//Clears the buffer with an image
long _stdcall FS_AllocateImage(colour_image* src, long lImageWidth, long lImageHeight, long lImageDepth);
//Allocates buffer for an image.
//Note this deallocates an existing buffer
long _stdcall FS_CreateImage(colour_image** img, long lImageWidth, long lImageHeight, long lImageDepth);
//Creates a new image and allocates a buffer of the specified size
long _stdcall FS_CreateEmptyImage(colour_image** img);
//Creates a new image without allocating a buffer
long _stdcall FS_CreateCopyImage(colour_image* src, colour_image** dest);
//Creates a new image which is a copy of an existing one.
//The increments may not be the same as the original.
long _stdcall FS_DeleteImage(colour_image** src);
//Deletes an image and its associated buffer
long _stdcall FS_WrapImage(colour_image** img, long lImageData, long lSize, long lImageWidth, long lImageHeight, long lImageDepth, long lXInc, long lYInc, long lZInc);
//Creates an image based around an existing buffer
//When this image is deleted the buffer will not be deleted
long _stdcall FS_CreateMapImage(colour_image* src, colour_image* *destimg, long lLeft, long lTop, long lRight, long lBottom);
//Creates an image based around an existing image
//When this image is deleted the buffer will not be deleted
long _stdcall FS_GetPlaneImage(colour_image* src, colour_image** destimg, long lPlane);
//Creates an image based around an existing colour plane
//When this image is deleted the buffer will not be deleted
long _stdcall FS_IsAllocated(colour_image* src);
//Indicates whether the image has a buffer allocated or not.
BOOL _stdcall FS_IsFSImage(colour_image* hImage);
//Indicates whether a handle refers to a valid image.
BOOL _stdcall FS_IsLibraryActivated();
//Is the library activated
void _stdcall FS_TerminateThreads();
//Terminates the image processing threads

//Image to/from memory functions
long _stdcall FS_ImageSizeInMemory(colour_image* src, long* lSize);
//The amount of memory required for the image.
long _stdcall FS_ImageToMemory(colour_image* src, void* pMemory);
//Copy image into a block of memory allocated elsewhere.
long _stdcall FS_DuplicateImageFromMemory(colour_image** pDest, void* pMemory);
//Copy image out of a block of memory into a new image - this duplicates the image in the block including its flags.
long _stdcall FS_CopyImageFromMemory(colour_image** pDest, void* pMemory);
//Copy image out of a block of memory into a new image - this creates a new image and copies the source image.
long _stdcall FS_WrapImageFromMemory(colour_image** pDest, void* pMemory);
//Create an image based on an image in a block of memory - this includes the flags.


//Image properties
long _stdcall FS_ImageWidth(colour_image* src);
long _stdcall FS_ImageHeight(colour_image* src);
long _stdcall FS_ImageDepth(colour_image* src);
long _stdcall FS_GetImageProperties(colour_image* src, long* lImageData, long* lSize, long* lImageWidth, long* lImageHeight, long* lImageDepth, long* lXInc, long* lYInc, long* lZInc);
long _stdcall FS_SetImageArea (colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long lValue);
long _stdcall FS_GetImagePixel (colour_image* src, long lX, long lY);
long _stdcall FS_SetImagePixel (colour_image* src, long lX, long lY, long lValue);
long _stdcall FS_SetImageProperties(colour_image* src, long lImageData, long lSize, long lImageWidth, long lImageHeight, long lImageDepth, long lXInc, long lYInc, long lZInc, long lFlags);
long _stdcall FS_FlipBGR(colour_image* src);
//Adjusts the buffer pointer and increment so the an RGB image becomes BGR and vice versa

//Image utilities
long _stdcall FS_ColourToMono(colour_image* src, colour_image** dest);
//Copies a colour image to a mono image
long _stdcall FS_CopyArea(colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lTargetX, long lTargetY);
//Copies an area of a source image to a target image
long _stdcall FS_CopyColourImage(colour_image* src, colour_image** dest, bool bReflect, bool bInvert, bool bRotate);
//Copies an entire image with the option to rotate reflect etc.

//Maths operations
long _stdcall FS_AddImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_PixelMap (colour_image* src, colour_image** dest, unsigned char *ucMap);
//Applies a pixel map to an existing image.
//The map is an array of 256 unsigned chars
long _stdcall FS_AddValue(colour_image* src, colour_image** dest, long lValue);
long _stdcall FS_AndImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_Binarise(colour_image* src, colour_image** dest, long lLowerThreshold, long lUpperThreshold);
long _stdcall FS_DifferenceImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_FindBestPlane (colour_image* src, long* lBestPlane);
long _stdcall FS_FindThreshold (colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long *plThreshold);
long _stdcall FS_LinearCorrelation(colour_image* imgRef, colour_image* imgSample, long* lResultOffset, double* dScore);
long _stdcall FS_LocalContrast(colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long lGranularityH, long lGranularityV, long lStepX, long lStepY);
long _stdcall FS_MaxImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_MeanImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_MinImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_MultiplyValue(colour_image* src, colour_image** dest, double dValue);
long _stdcall FS_NegateImage(colour_image* src, colour_image** dest);
long _stdcall FS_OrImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_RescaleImage(colour_image* src, colour_image** pdest, long lOffset, double dMultiplier);
long _stdcall FS_SmartBinarise(colour_image* src, colour_image** dest, long lL, long lT, long lR, long lB, long lXFilterSize, long lYFilterSize, long lMinContrast, long lMinThreshold, long lMaxThreshold);
long _stdcall FS_SmoothedImage(colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long lGranularityH, long lGranularityV, long lStepX, long lStepY);
//Binarises an image based on local threshold
//lXFilterSize and lYFilterSize define the block size
//lMinContrast is the contrast required for a block not to be defined as uniform in colour
//lMinThreshold and lMaxThreshold are values below and above which the pixel is light or dark regardless of an local threshold
long _stdcall FS_SobelAngle (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long lThreshold);
long _stdcall FS_SobelEmboss (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom);
long _stdcall FS_SobelFilter (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom);
long _stdcall FS_SobelToMono (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom);
long _stdcall FS_SubtractImage(colour_image* src1, colour_image* src2, colour_image** dest);
long _stdcall FS_Corner(colour_image* src, colour_image** pdest, long lTileSizeX, long lTileSizeY);

//Transforms
long _stdcall FS_SetTransformData(transform_data** ptdTransform, double dM00, double dM01, double dM10, double dM11, double dX, double dY);
long _stdcall FS_DeleteTransformData(transform_data** ptdTransform);
long _stdcall FS_TransformPoint(transform_data* tdTransform, double dX, double dY, double* pdX, double* pdY);
long _stdcall FS_InverseTransformPoint(transform_data* tdTransform, double dX, double dY, double* pdX, double* pdY);
long _stdcall FS_TransformMerge(transform_data* tdTransform1, transform_data* tdTransform2, transform_data** ptdTransformResult);
long _stdcall FS_CreateShearTransform(transform_data** ptdTransform, double dHorizontalShearAngle, double dVerticalShearAngle);
long _stdcall FS_CreateRotateTransform(transform_data** ptdTransform, double dAngle);
long _stdcall FS_CreateRescaleTransform(transform_data** ptdTransform, double dHorizontalScale, double dVerticalScale);
long _stdcall FS_CreateTranslateTransform(transform_data** ptdTransform, double dHorizontalOffset, double dVerticalOffset);
long _stdcall FS_AffineTransform (colour_image* src, colour_image** pdest, transform_data* tdTransform, long lOriginX, long lOriginY);
long _stdcall FS_ExpandImage (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lGranularity);
long _stdcall FS_ExpandImageHV (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long lGranularityX, long lGranularityY);
long _stdcall FS_PolarUnwrap (colour_image* src, colour_image** dest, long lCentreX, long lCentreY, long lInnerRadius, long lOuterRadius, long lStartAngle, long lEndAngle);
long _stdcall FS_ProjectH (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom);
long _stdcall FS_ProjectV (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom);
long _stdcall FS_RotateCircleSmoothed (colour_image* src, colour_image** pdest, long lCentreX, long lCentreY, long lRadius, double dAngle);
long _stdcall FS_RotateImage (colour_image* src, colour_image** dest, long lCentreX, long lCentreY, double dAngle);
long _stdcall FS_RotateImageSmoothed (colour_image* src, colour_image** dest, long lCentreX, long lCentreY, double dAngle);
long _stdcall FS_HoughTransform (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lSobelThreshold, long lMinAngle, long lMaxAngle);
long _stdcall FS_HoughEnhancedTransform (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long lSobelThreshold, long lMinAngle, long lMaxAngle);
long _stdcall FS_SelectColour (colour_image* src, colour_image** pdest, long lRed, long lGreen, long lBlue, double dColourTolerance, long lBrightnessTolerance);
//Brightness tolerance is in grey levels, colour tolerance is in degrees
long _stdcall FS_ShrinkImage (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lGranularity);
//Shrink an image taking every nth pixel
long _stdcall FS_ShrinkMax (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lGranularity);
//Shrink an image taking the brightest pixel in each block
long _stdcall FS_ShrinkMin (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lGranularity);
//Shrink an image taking the darkest pixel in each block
long _stdcall FS_ShrinkImageSmoothed (colour_image* src, colour_image** dest, long lLeft, long lTop, long lRight, long lBottom, long lGranularity);
//Shrink an image taking the average of the pixels in each block
long _stdcall FS_ShrinkImageSmoothedHV (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long lGranularityH, long lGranularityV);
//Shrink an image taking the average of the pixels in each block with different granularities in different directions
long _stdcall FS_CylinderUnwrapV (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom);

//Blob
long _stdcall FS_BlobUse(colour_image* src, long* results, long lLowThreshold, long lHighThreshold, long lLeft, long lTop, long lRight, long lBottom, long* lNumberOfBlobsFound);
long _stdcall FS_BlobUseEx(long params, colour_image* src, long* results, long lLeft, long lTop, long lRight, long lBottom, long* lNumberOfBlobsFound);
long _stdcall FS_BlobUseLightBlobs(colour_image* src, long* results, long lLeft, long lTop, long lRight, long lBottom, long* lNumberOfBlobsFound);
long _stdcall FS_BlobUseDarkBlobs(colour_image* src, long* results, long lLeft, long lTop, long lRight, long lBottom, long* lNumberOfBlobsFound);
long _stdcall FS_SetBlobParams(long* params, long lLowThreshold, long lHighThreshold, long lMaxNumberOfBlobs, long lMaxTotalArea, long lMinBlobArea, long lMaxBlobArea);
long _stdcall FS_DeleteBlobParams(long* params);
long _stdcall FS_DeleteBlobResults(long* results);
long _stdcall FS_BlobGet(long results, long lIndex, long* pBlob);
long _stdcall FS_BlobArea(long pBlob);
double _stdcall FS_BlobCentreX(long pBlob);
double _stdcall FS_BlobCentreY(long pBlob);
long _stdcall FS_BlobMinX(long pBlob);
long _stdcall FS_BlobMinY(long pBlob);
long _stdcall FS_BlobMaxX(long pBlob);
long _stdcall FS_BlobMaxY(long pBlob);
long _stdcall FS_BlobBasicInfo(long pBlob, long* lArea, double* dCentreX, double* dCentreY);
long _stdcall FS_BlobPaint(long pBlob, colour_image* dest, long lLeft, long lTop, long lFillHoles);
long _stdcall FS_BlobPerimeterLength(long pBlob, long* pLength);
long _stdcall FS_BlobPerimeterPoint(long pBlob, long lIndex, long* plPointX, long* plPointY);
long _stdcall FS_BlobMaxDiameter(long pBlob, long* pDiameter);
long _stdcall FS_BlobAngle(long pBlob, double* pdAngle);
long _stdcall FS_BlobRoundness(long pBlob, double* pdRoundness);
long _stdcall FS_BlobTotalArea(long results);
long _stdcall FS_BlobLargest(long lResults, long* pLargestBlob);
long _stdcall FS_BlobNext(long lBlob, long* pNext);
long _stdcall FS_BlobHoleArea(long lBlob, long* lHoleArea);
long _stdcall FS_BlobCompareResults(void* Reference, void* Test, long lAreaTolerancePercent, long lDistanceTolerancePercent, long lAngleToleranceDegress, long* lScore, long* lAngleDegrees, long* lOffsetX, long* lOffsetY);
//Code reading
long _stdcall FS_FindCodes(colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long lMinCharWidth, long lMinCharHeight, long lBlackLevel, long lWhiteLevel, long lMinContrast, long lFilter, long lSharpness, long lDarkCharacters, void** pResults, long* lNumberOfCodes);
long _stdcall FS_GetCode(void* pResults, long lIndex, long* lCharacterHeight, long* lMinX, long* lMinY, long* lMaxX, long* lMaxY);
long _stdcall FS_DeleteCode(void** pResults);
long _stdcall FS_AutoSegment(colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long *plNumberOfResults, rect_data** pResults);

//Search models
long _stdcall FS_OSModelTrain (colour_image *src, long lPlane, long* pTrainedModel, long lLeft, long lTop, long lRight, long lBottom, long lMaxScale, long lQuality);
//Train a model
long _stdcall FS_OSModelUse (colour_image *src, colour_image **pdest, long pTrainedModel, long lScore, long lLeft, long lTop, long lRight, long lBottom, double *dResultX, double *dResultY, double *dScore, long *plResultCount, long *FullResults);
//Use a model to find up to 100 results
long _stdcall FS_OSModelUseEx (colour_image *src, colour_image **pdest, long lPlane, long pTrainedModel, long pSearchParams, long lLeft, long lTop, long lRight, long lBottom, double *dResultX, double *dResultY, double *dScore, long *plResultCount, long *FullResults);
//Use a model with full parameter control
long _stdcall FS_OSModelUseSingle (colour_image *src, long pTrainedModel, long lScore, long lLeft, long lTop, long lRight, long lBottom, double *dResultX, double *dResultY, double *dScore);
//Use a model to find the best single result
long _stdcall FS_OSModelUseFirst (colour_image *src, long pTrainedModel, long lScore, long lLeft, long lTop, long lRight, long lBottom, double *dResultX, double *dResultY, double *dScore);
//Use a model to find the first result and then stop
long _stdcall FS_OSModelDelete (long* pTrainedModel);
long _stdcall FS_OSModelGetIdentifier (long pTrainedModel);
long _stdcall FS_OSModelGetPlane (long pTrainedModel);
//Get the colour plane a model was originally trained on
long _stdcall FS_OSModelGetScale (long pTrainedModel);
//Get the detail level of a model
long _stdcall FS_OSModelGetImage (long lTrainedModel, colour_image** pImage);
long _stdcall FS_OSModelLoad (long* lpModel, char* sFileName);
long _stdcall FS_OSModelSave (long* lModel,  char* sFileName);
long _stdcall FS_OSCreateSearchParams (long* pSearchParams, long lMaxResults, long lMinScore, long lOptimumScore, bool bHighAccuracy);
long _stdcall FS_OSDeleteSearchParams (long* pSearchParams);
long _stdcall FS_OSGetResult (long pResults, long lIndex, double *dResultX, double *dResultY, double *dScore);
long _stdcall FS_OSDeleteResults (long* pResults);

//Search model lists
//Note indicies are one based
//Models and their images must not be deleted externally
long _stdcall FS_OSModelListAddModel (long *plModelList, long pModel, long lIdentifier);
long _stdcall FS_OSModelListAddModelEx (long *plModelList, long* plIndex, long pModel, long lIdentifier);
long _stdcall FS_OSModelListModel (long pModelList, long lIndex, long* plModel);
long _stdcall FS_OSModelListDeleteItem (long *plModelList, long lIndex, BOOL bDeleteModel);
long _stdcall FS_OSModelListDelete (long* pModelList, BOOL bDeleteModels);
//Delete a model list and the models referenced.
long _stdcall FS_OSModelListUse (colour_image *src, long lPlane, long pModelList, long lMinScore, long lLeft, long lTop, long lRight, long lBottom, long *plResultCount, long *FullResults);
long _stdcall FS_OSModelListUseSingle (colour_image *src, long lPlane, long pModelList, long lMinScore, long lLeft, long lTop, long lRight, long lBottom, long *plResultCount, long *FullResults);
long _stdcall FS_OSModelListUseFirst (colour_image *src, long lPlane, long pModelList, long lMinScore, long lLeft, long lTop, long lRight, long lBottom, long *plResultCount, long *FullResults);
long _stdcall FS_OSModelListResult (long pResults, long lIndex, double *dResultX, double *dResultY, double *dScore, long* lIdentifier);
long _stdcall FS_OSGetModelListCount (long pModelList, long* lModels);
//Getthe number of models in a list
long _stdcall FS_OSModelListExtent (long pModelList, long* plMaxWidth, long *plMaxHeight);
//Get the largest dimensions of the models
//The largest model dimension in each direction - not necessarily the same model
long _stdcall FS_OSModelListFontImage (colour_image** pFontImage, long lModelList, long* plThumbnailSizeX, long* plThumbnailSizeY);
//Create a composite image of the font
long _stdcall FS_OSModelListLoad (long* lpModelList, char* sFileName);
long _stdcall FS_OSModelListSave (long* lModelList, char* sFileName);

//Colour
long _stdcall FS_GetColourProfile (colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long** hProfile);
long _stdcall FS_CompareColourProfiles (long* hProfileSrc1, long* hProfileSrc2, long* plScore);
long _stdcall FS_MergeColourProfiles (long* hProfileSrc1, long* hProfileSrc2, long** hProfileDest);
long _stdcall FS_Posterise (colour_image* src, colour_image** pdest);
long _stdcall FS_LoadColourProfile (long** hProfile, char* sFileName);
long _stdcall FS_SaveColourProfile (long* hProfile, char* sFileName);
long _stdcall FS_SelectColourProfile (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long* hProfile);
long _stdcall FS_CreateColourProfileMask (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long* hProfile);
long _stdcall FS_AddColourRegionToProfile (long* hProfile, long lColourRGB, long lWeight, double dColourTolerance, long lBrightnessTolerance);
long _stdcall FS_DeleteColourProfile (long** hProfile);
long _stdcall FS_CopyColourProfile (long* hProfileSrc, long** hProfileDest);
long _stdcall FS_ExpandColourProfile (long* hProfile, double dColourTolerance, long lBrightnessTolerance);
long _stdcall FS_CreateColourProfileImage (long* hProfile, colour_image** hDest);
long _stdcall FS_CompareColourRange (long* hProfileSrc1, long* hProfileSrc2, long* plScore);
long _stdcall FS_RemoveColourRegionFromProfile (long** hProfile, long lColourRGB, double dColourTolerance, long lBrightnessTolerance);

//Other
long _stdcall FS_DrawStretchedCircle(colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long lValue, bool bAdd);
long _stdcall FS_FindAngle (colour_image* src, colour_image** pdest, long lLeft, long lTop, long lRight, long lBottom, long *plAngle, long lSobelThreshold, long lMinAngle, long lMaxAngle);
long _stdcall FS_FindEdge (colour_image* src, long lRow, long lStart, long lEnd, long lMinContrast, long lFilterWidth, long *plResult, long *plContrast);
long _stdcall FS_HistogramEllipse(colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long *HGram);
long _stdcall FS_HistogramROI(colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long *HGram);
long _stdcall FS_HistogramInfo(long *HGram, long lLeftTailPercentage, long lRightTailPercentage, long *lLeftTail, long *lRightTail, long *lMean, long *lMedian, long *lEnergy, long *lPixels);
long _stdcall FS_HistogramInfoROI(colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long lLeftTailPercentage, long lRightTailPercentage, long *lLeftTail, long *lRightTail, long *lMean, long *lMedian, long *lEnergy);
long _stdcall FS_HistogramInfoEllipse(colour_image* src, long lLeft, long lTop, long lRight, long lBottom, long lLeftTailPercentage, long lRightTailPercentage, long *lLeftTail, long *lRightTail, long *lMean, long *lMedian, long *lEnergy);
double _stdcall FS_ArcCos (double dValue);
double _stdcall FS_ArcSin (double dValue);
double _stdcall FS_RadiansToDegrees (double dValue);
double _stdcall FS_DegreesToRadians (double dValue);
double _stdcall FS_AngleFromPoint (long lPointX, long lPointY);	//In the range 0-360, measured clockwise from the 3 o'clock position.


//Extras
long _stdcall FS_LoadImage(char* sFileName, colour_image** pdest); 
long _stdcall FS_SaveImage(colour_image* hImage, char* sFileName); 
long _stdcall FS_ImageTohDC(colour_image* hImage, HDC hDC, long lTargetLeftPixels, long lTargetTopPixels, long lTargetWidthPixels, long lTargetHeightPixels);
long _stdcall FS_ImageAreaTohDC(colour_image* src, HDC hDC, long lLeft, long lTop, long lRight, long lBottom, long lTargetLeftPixels, long lTargetTopPixels, long lTargetWidthPixels, long lTargetHeightPixels);
long _stdcall FS_ImageToPicture(colour_image* hImage, LPPICTUREDISP *pPicture);
long _stdcall FS_ImageToClipboard(colour_image* hImage, HWND hWnd);
//Sadly this results in a 24bit image even for a monochrome source
long _stdcall FS_CheckRegistration();
long _stdcall FS_ActivateLibraries(char* sForeshoreKey);
long _stdcall FS_ActivateLibrariesSerial(char* sSerialNumber, char* sForeshoreKey, char* sReqKey);
//Checks registration details and activates the library if they exist
//Start in demo mode otherwise
long _stdcall FS_ResetTimeMicroSeconds();
//Resets the internal timer
double _stdcall FS_GetTimeMicroSeconds();
double FS_Sqrt(double n);
